============================
The cli of Serverless Cloud Function
# This is a local tools for SCF.
## Quick Start
First, install the library:
```
$ pip install tcf
```

or download source code from github and install:

```
$ git clone https://github.com/tencentyun/tcfcli.git
$ cd tcfcli
$ python setup.py -e .
```
